"""
    airQ - Air Quality monitoring data ( for India ) collection system, written in Python3.

    This application is available on PyPI.

    $ pip install airQ --user
    or
    $ python3 -m pip install airQ --user

    Using systemd, to automate data collecetion, which is to be explored.

    Data collection is done is hourly fashion.
"""

__author__ = 'Anjan Roy<anjanroy@yandex.com>'
__version__ = '0.3.1'
